@@ -13,7 +13,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2008 XNeur Team
+ *  Copyright (C) 2006-2009 XNeur Team
  *
  */
 
@@ -93,28 +93,13 @@ GtkWidget* create_menu_icon(struct _tray_icon *tray, gboolean runned, int state)
 	gtk_widget_show(menuitem);
 	gtk_container_add(GTK_CONTAINER(menu), menuitem);
 	g_signal_connect(G_OBJECT(menuitem), "activate", G_CALLBACK(xneur_start_stop), tray);
-	
-	// State
-	if (state == 0) // Auto
-	{
-		menu_text = _("Disable input auto-correction");
-		menu_icon = "gtk-disconnect";
-	}
-	else // Manual
-	{
-		menu_text = _("Enable input auto-correction");
-		menu_icon = "gtk-connect";
-	}
 
-	menuitem = gtk_image_menu_item_new_with_mnemonic(menu_text);
-	image = gtk_image_new_from_stock(menu_icon, GTK_ICON_SIZE_MENU);
-	gtk_widget_set_name(image, "image");
-	gtk_widget_show(image);
-	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuitem), image);
+	menu_text = _("Auto-correction");
+	menuitem = gtk_check_menu_item_new_with_mnemonic(menu_text);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem), !state);
 	gtk_widget_show(menuitem);
 	gtk_container_add(GTK_CONTAINER(menu), menuitem);
 	g_signal_connect(G_OBJECT(menuitem), "activate", G_CALLBACK(xneur_auto_manual), tray);
-
 	if (runned == FALSE)
 		gtk_widget_set_sensitive(menuitem, FALSE);
 	
@@ -168,9 +153,10 @@ void clock_check(Clock *clock)
 
 void create_tray_icon(struct _tray_icon *tray, gboolean runned)
 {
-	char *layout_name = xconfig->get_lang_name(xconfig, xconfig->find_group_lang(xconfig, get_active_keyboard_group()));
-	if (layout_name == NULL) 
-		layout_name = "gxneur";
+	char *layout_name = "gxneur";
+	int lang = xconfig->find_group_lang(xconfig, get_active_keyboard_group());
+	if (lang != -1)
+		layout_name = xconfig->languages[xconfig->find_group_lang(xconfig, get_active_keyboard_group())].dir;
 
 	char *image_file = g_strdup_printf("%s%s", layout_name, ".png");
 	
